==> grf_0.10.1.tar.gz: grf/src/src/splitting/factory/ProbabilitySplittingRuleFactory.cpp <==
/*-------------------------------------------------------------------------------
  This file is part of generalized random forest (grf).

  grf is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 3 of the License, or
  (at your option) any later version.

  grf is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with grf. If not, see <http://www.gnu.org/licenses/>.
 #-------------------------------------------------------------------------------*/

#include <unordered_map>
#include "splitting/SplittingRule.h"
#include "splitting/factory/ProbabilitySplittingRuleFactory.h"
#include "splitting/ProbabilitySplittingRule.h"

ProbabilitySplittingRuleFactory::ProbabilitySplittingRuleFactory(size_t num_classes):
    num_classes(num_classes) {}

std::shared_ptr<SplittingRule> ProbabilitySplittingRuleFactory::create(Data* data,
                                                                       const Observations& observations,
                                                                       const TreeOptions& options) {
  return std::shared_ptr<SplittingRule>(new ProbabilitySplittingRule(
      data, num_classes, options.get_alpha(), options.get_imbalance_penalty()));
}

==> grf_0.10.4.tar.gz: grf/src/src/splitting/factory/ProbabilitySplittingRuleFactory.cpp <==
/*-------------------------------------------------------------------------------
  This file is part of generalized random forest (grf).

  grf is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 3 of the License, or
  (at your option) any later version.

  grf is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with grf. If not, see <http://www.gnu.org/licenses/>.
 #-------------------------------------------------------------------------------*/

#include "splitting/SplittingRule.h"
#include "splitting/factory/ProbabilitySplittingRuleFactory.h"
#include "splitting/ProbabilitySplittingRule.h"

namespace grf {

ProbabilitySplittingRuleFactory::ProbabilitySplittingRuleFactory(size_t num_classes):
    num_classes(num_classes) {}

std::unique_ptr<SplittingRule> ProbabilitySplittingRuleFactory::create(const Data& data,
                                                                       const TreeOptions& options) const {
  return std::unique_ptr<SplittingRule>(new ProbabilitySplittingRule(
      data.get_max_num_unique_values(),
      num_classes,
      options.get_alpha(),
      options.get_imbalance_penalty()));
}

} // namespace grf
